@@ -4,7 +4,6 @@ Example script showing how to use the LaceworkClient class.
 """
 
 import logging
-import os
 
 from dotenv import load_dotenv
 from laceworksdk import LaceworkClient
@@ -15,10 +14,8 @@ load_dotenv()
 
 if __name__ == "__main__":
 
-    # Use enviroment variables to instantiate a LaceworkClient instance
-    lacework_client = LaceworkClient(api_key=os.getenv("LW_API_KEY"),
-                                     api_secret=os.getenv("LW_API_SECRET"),
-                                     account=os.getenv("LW_ACCOUNT"))
+    # Instantiate a LaceworkClient instance
+    lacework_client = LaceworkClient()
 
     # Alert Channels API
 
