@@ -22,7 +22,12 @@ class TestConfigsEndpoint(SearchEndpoint):
 
     OBJECT_TYPE = InventoryAPI
 
+    @pytest.mark.parametrize("csp", ["AWS", "Azure", "GCP"])
+    def test_api_search_by_date(self, api_object, csp):
+
+        return super().test_api_search_by_date(api_object=api_object, filters={"csp": csp})
+
     @pytest.mark.parametrize("dataset", ["AwsCompliance", "GcpCompliance"])
-    def test_api_search_by_date(self, api_object, dataset):
+    def test_api_search_by_date_deprecated(self, api_object, dataset):
 
         return super().test_api_search_by_date(api_object=api_object, filters={"dataset": dataset})
